@@ -4,4 +4,6 @@ from .t2t import cache_ontology_set
 from .t2t import cache_ontology
 from .t2t import cache_exists
 from .t2t import clear_cache
-from .mapper import Mapper
\ No newline at end of file
+from .mapper import Mapper
+from .preprocess import preprocess_file
+from .preprocess import preprocess_terms
\ No newline at end of file
